==> opensubdiv-3.4.3-4-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/hierarchy.js <==
var hierarchy =
[
    [ "TopologyRefiner::AdaptiveOptions", "a00917.html", null ],
    [ "BufferDescriptor", "a00929.html", null ],
    [ "PatchMap::QuadNode::Child", "a00781.html", null ],
    [ "Refinement::ChildTag", "a01217.html", null ],
    [ "CLEvaluator", "a00937.html", null ],
    [ "CLStencilTable", "a00933.html", null ],
    [ "CLVertexBuffer", "a00945.html", null ],
    [ "ConstArray< TYPE >", "a01145.html", [
      [ "Array< TYPE >", "a01149.html", null ]
    ] ],
    [ "ConstArray< Index >", "a01145.html", [
      [ "Array< Index >", "a01149.html", null ]
    ] ],
    [ "CpuD3D11VertexBuffer", "a00949.html", null ],
    [ "CpuEvaluator", "a00953.html", null ],
    [ "CpuGLVertexBuffer", "a00957.html", null ],
    [ "CPUMTLVertexBuffer", "a01097.html", null ],
    [ "CpuPatchTable", "a00961.html", null ],
    [ "CpuVertexBuffer", "a00965.html", null ],
    [ "Crease", "a01125.html", null ],
    [ "FVarLevel::CreaseEndPair", "a01177.html", null ],
    [ "CudaEvaluator", "a00973.html", null ],
    [ "CudaStencilTable", "a00969.html", null ],
    [ "CudaVertexBuffer", "a00981.html", null ],
    [ "D3D11ComputeEvaluator", "a00989.html", null ],
    [ "D3D11StencilTable", "a00985.html", null ],
    [ "D3D11VertexBuffer", "a01001.html", null ],
    [ "EdgeInterface", "a01157.html", null ],
    [ "EvaluatorCacheT< EVALUATOR >::Entry", "a01065.html", null ],
    [ "FVarLevel::ETag", "a01169.html", null ],
    [ "Level::ETag", "a01193.html", null ],
    [ "EvaluatorCacheT< EVALUATOR >", "a01061.html", null ],
    [ "FaceInterface", "a01153.html", null ],
    [ "Level::FTag", "a01197.html", null ],
    [ "TopologyDescriptor::FVarChannel", "a00897.html", null ],
    [ "FVarLevel", "a01165.html", null ],
    [ "FVarRefinement", "a01181.html", null ],
    [ "GLComputeEvaluator", "a01009.html", null ],
    [ "GLSLPatchShaderSource", "a01029.html", null ],
    [ "GLStencilTableSSBO", "a01005.html", null ],
    [ "GLStencilTableTBO", "a01037.html", null ],
    [ "GLVertexBuffer", "a01033.html", null ],
    [ "GLXFBEvaluator", "a01041.html", null ],
    [ "HLSLPatchShaderSource", "a01053.html", null ],
    [ "Level", "a01185.html", null ],
    [ "LimitStencilTableFactoryReal< REAL >", "a00837.html", null ],
    [ "LimitStencilTableFactoryReal< float >", "a00837.html", [
      [ "LimitStencilTableFactory", "a00889.html", null ]
    ] ],
    [ "Scheme< SCHEME_TYPE >::LocalMask< WEIGHT >", "a01137.html", null ],
    [ "LimitStencilTableFactoryReal< REAL >::LocationArray", "a00881.html", null ],
    [ "MeshInterface< PATCH_TABLE >", "a01057.html", [
      [ "Mesh< VERTEX_BUFFER, STENCIL_TABLE, EVALUATOR, PATCH_TABLE, DEVICE_CONTEXT >", "a01069.html", null ]
    ] ],
    [ "MTLComputeEvaluator", "a01081.html", null ],
    [ "MTLContext", "a01073.html", null ],
    [ "MTLPatchShaderSource", "a01089.html", null ],
    [ "MTLStencilTable", "a01077.html", null ],
    [ "NonCopyable< T >", "a01101.html", null ],
    [ "NonCopyable< CLPatchTable >", "a01101.html", [
      [ "CLPatchTable", "a00941.html", null ]
    ] ],
    [ "NonCopyable< CudaPatchTable >", "a01101.html", [
      [ "CudaPatchTable", "a00977.html", null ]
    ] ],
    [ "NonCopyable< D3D11LegacyGregoryPatchTable >", "a01101.html", [
      [ "D3D11LegacyGregoryPatchTable", "a00993.html", null ]
    ] ],
    [ "NonCopyable< D3D11PatchTable >", "a01101.html", [
      [ "D3D11PatchTable", "a00997.html", null ]
    ] ],
    [ "NonCopyable< GLLegacyGregoryPatchTable >", "a01101.html", [
      [ "GLLegacyGregoryPatchTable", "a01021.html", null ]
    ] ],
    [ "NonCopyable< GLPatchTable >", "a01101.html", [
      [ "GLPatchTable", "a01025.html", null ]
    ] ],
    [ "NonCopyable< MTLLegacyGregoryPatchTable >", "a01101.html", [
      [ "MTLLegacyGregoryPatchTable", "a01085.html", null ]
    ] ],
    [ "NonCopyable< MTLPatchTable >", "a01101.html", [
      [ "MTLPatchTable", "a01093.html", null ]
    ] ],
    [ "OmpEvaluator", "a01105.html", null ],
    [ "Refinement::Options", "a01209.html", null ],
    [ "TopologyRefinerFactory< MESH >::Options", "a00925.html", null ],
    [ "PatchTableFactory::Options", "a00809.html", null ],
    [ "Options", "a01129.html", null ],
    [ "StencilTableFactoryReal< REAL >::Options", "a00873.html", null ],
    [ "LimitStencilTableFactoryReal< REAL >::Options", "a00877.html", null ],
    [ "PatchArray", "a01117.html", null ],
    [ "PatchCoord", "a01113.html", null ],
    [ "PatchDescriptor", "a00769.html", null ],
    [ "PatchTableFactory::PatchFaceTag", "a00813.html", null ],
    [ "PatchTable::PatchHandle", "a00793.html", null ],
    [ "PatchMap", "a00773.html", null ],
    [ "PatchParam", "a00785.html", [
      [ "PatchParam", "a01121.html", null ]
    ] ],
    [ "PatchTable", "a00789.html", null ],
    [ "PatchTableFactory", "a00805.html", null ],
    [ "PrimvarRefinerReal< REAL >", "a00817.html", null ],
    [ "PrimvarRefinerReal< float >", "a00817.html", [
      [ "PrimvarRefiner", "a00825.html", null ]
    ] ],
    [ "PtexIndices", "a00829.html", null ],
    [ "Refinement", "a01205.html", null ],
    [ "Refinement::Relations", "a01221.html", null ],
    [ "Scheme< SCHEME_TYPE >", "a01133.html", null ],
    [ "SchemeTypeTraits", "a01141.html", null ],
    [ "SparseSelector", "a01225.html", null ],
    [ "Refinement::SparseTag", "a01213.html", null ],
    [ "StackBuffer< TYPE, SIZE, POD_TYPE >", "a01229.html", null ],
    [ "StencilReal< REAL >", "a00841.html", [
      [ "LimitStencilReal< REAL >", "a00857.html", null ]
    ] ],
    [ "StencilReal< float >", "a00841.html", [
      [ "LimitStencilReal< float >", "a00857.html", [
        [ "LimitStencil", "a00861.html", null ]
      ] ],
      [ "Stencil", "a00845.html", null ]
    ] ],
    [ "StencilTableFactoryReal< REAL >", "a00833.html", null ],
    [ "StencilTableFactoryReal< float >", "a00833.html", [
      [ "StencilTableFactory", "a00885.html", null ]
    ] ],
    [ "StencilTableReal< REAL >", "a00849.html", [
      [ "LimitStencilTableReal< REAL >", "a00865.html", null ]
    ] ],
    [ "StencilTableReal< float >", "a00849.html", [
      [ "LimitStencilTableReal< float >", "a00865.html", [
        [ "LimitStencilTable", "a00869.html", null ]
      ] ],
      [ "StencilTable", "a00853.html", null ]
    ] ],
    [ "TbbEvaluator", "a01109.html", null ],
    [ "TopologyDescriptor", "a00893.html", null ],
    [ "TopologyLevel", "a00901.html", null ],
    [ "TopologyRefiner", "a00909.html", null ],
    [ "TopologyRefinerFactory< MESH >", "a00905.html", null ],
    [ "TopologyRefinerFactoryBase", "a00921.html", null ],
    [ "TopologyRefiner::UniformOptions", "a00913.html", null ],
    [ "FVarLevel::ValueTag", "a01173.html", null ],
    [ "VertexInterface", "a01161.html", null ],
    [ "Level::VSpan", "a01201.html", null ],
    [ "Level::VTag", "a01189.html", null ]
];

==> opensubdiv-3.4.4-10-armv7h.pkg.tar.xz: usr/share/doc/opensubdiv/doxy_html/hierarchy.js <==
var hierarchy =
[
    [ "TopologyRefiner::AdaptiveOptions", "a00917.html", null ],
    [ "BufferDescriptor", "a00929.html", null ],
    [ "PatchMap::QuadNode::Child", "a00781.html", null ],
    [ "Refinement::ChildTag", "a01217.html", null ],
    [ "CLEvaluator", "a00937.html", null ],
    [ "CLStencilTable", "a00933.html", null ],
    [ "CLVertexBuffer", "a00945.html", null ],
    [ "ConstArray< TYPE >", "a01145.html", [
      [ "Array< TYPE >", "a01149.html", null ]
    ] ],
    [ "ConstArray< Index >", "a01145.html", [
      [ "Array< Index >", "a01149.html", null ]
    ] ],
    [ "CpuD3D11VertexBuffer", "a00949.html", null ],
    [ "CpuEvaluator", "a00953.html", null ],
    [ "CpuGLVertexBuffer", "a00957.html", null ],
    [ "CPUMTLVertexBuffer", "a01097.html", null ],
    [ "CpuPatchTable", "a00961.html", null ],
    [ "CpuVertexBuffer", "a00965.html", null ],
    [ "Crease", "a01125.html", null ],
    [ "FVarLevel::CreaseEndPair", "a01177.html", null ],
    [ "CudaEvaluator", "a00973.html", null ],
    [ "CudaStencilTable", "a00969.html", null ],
    [ "CudaVertexBuffer", "a00981.html", null ],
    [ "D3D11ComputeEvaluator", "a00989.html", null ],
    [ "D3D11StencilTable", "a00985.html", null ],
    [ "D3D11VertexBuffer", "a01001.html", null ],
    [ "EdgeInterface", "a01157.html", null ],
    [ "EvaluatorCacheT< EVALUATOR >::Entry", "a01065.html", null ],
    [ "FVarLevel::ETag", "a01169.html", null ],
    [ "Level::ETag", "a01193.html", null ],
    [ "EvaluatorCacheT< EVALUATOR >", "a01061.html", null ],
    [ "FaceInterface", "a01153.html", null ],
    [ "Level::FTag", "a01197.html", null ],
    [ "TopologyDescriptor::FVarChannel", "a00897.html", null ],
    [ "FVarLevel", "a01165.html", null ],
    [ "FVarRefinement", "a01181.html", null ],
    [ "GLComputeEvaluator", "a01009.html", null ],
    [ "GLSLPatchShaderSource", "a01029.html", null ],
    [ "GLStencilTableSSBO", "a01005.html", null ],
    [ "GLStencilTableTBO", "a01037.html", null ],
    [ "GLVertexBuffer", "a01033.html", null ],
    [ "GLXFBEvaluator", "a01041.html", null ],
    [ "HLSLPatchShaderSource", "a01053.html", null ],
    [ "Level", "a01185.html", null ],
    [ "LimitStencilTableFactoryReal< REAL >", "a00837.html", null ],
    [ "LimitStencilTableFactoryReal< float >", "a00837.html", [
      [ "LimitStencilTableFactory", "a00889.html", null ]
    ] ],
    [ "Scheme< SCHEME_TYPE >::LocalMask< WEIGHT >", "a01137.html", null ],
    [ "LimitStencilTableFactoryReal< REAL >::LocationArray", "a00881.html", null ],
    [ "MeshInterface< PATCH_TABLE >", "a01057.html", [
      [ "Mesh< VERTEX_BUFFER, STENCIL_TABLE, EVALUATOR, PATCH_TABLE, DEVICE_CONTEXT >", "a01069.html", null ]
    ] ],
    [ "MTLComputeEvaluator", "a01081.html", null ],
    [ "MTLContext", "a01073.html", null ],
    [ "MTLPatchShaderSource", "a01089.html", null ],
    [ "MTLStencilTable", "a01077.html", null ],
    [ "NonCopyable< T >", "a01101.html", null ],
    [ "NonCopyable< CLPatchTable >", "a01101.html", [
      [ "CLPatchTable", "a00941.html", null ]
    ] ],
    [ "NonCopyable< CudaPatchTable >", "a01101.html", [
      [ "CudaPatchTable", "a00977.html", null ]
    ] ],
    [ "NonCopyable< D3D11LegacyGregoryPatchTable >", "a01101.html", [
      [ "D3D11LegacyGregoryPatchTable", "a00993.html", null ]
    ] ],
    [ "NonCopyable< D3D11PatchTable >", "a01101.html", [
      [ "D3D11PatchTable", "a00997.html", null ]
    ] ],
    [ "NonCopyable< GLLegacyGregoryPatchTable >", "a01101.html", [
      [ "GLLegacyGregoryPatchTable", "a01021.html", null ]
    ] ],
    [ "NonCopyable< GLPatchTable >", "a01101.html", [
      [ "GLPatchTable", "a01025.html", null ]
    ] ],
    [ "NonCopyable< MTLLegacyGregoryPatchTable >", "a01101.html", [
      [ "MTLLegacyGregoryPatchTable", "a01085.html", null ]
    ] ],
    [ "NonCopyable< MTLPatchTable >", "a01101.html", [
      [ "MTLPatchTable", "a01093.html", null ]
    ] ],
    [ "OmpEvaluator", "a01105.html", null ],
    [ "LimitStencilTableFactoryReal< REAL >::Options", "a00877.html", null ],
    [ "PatchTableFactory::Options", "a00809.html", null ],
    [ "StencilTableFactoryReal< REAL >::Options", "a00873.html", null ],
    [ "TopologyRefinerFactory< MESH >::Options", "a00925.html", null ],
    [ "Options", "a01129.html", null ],
    [ "Refinement::Options", "a01209.html", null ],
    [ "PatchArray", "a01117.html", null ],
    [ "PatchCoord", "a01113.html", null ],
    [ "PatchDescriptor", "a00769.html", null ],
    [ "PatchTableFactory::PatchFaceTag", "a00813.html", null ],
    [ "PatchTable::PatchHandle", "a00793.html", null ],
    [ "PatchMap", "a00773.html", null ],
    [ "PatchParam", "a00785.html", [
      [ "PatchParam", "a01121.html", null ]
    ] ],
    [ "PatchTable", "a00789.html", null ],
    [ "PatchTableFactory", "a00805.html", null ],
    [ "PrimvarRefinerReal< REAL >", "a00817.html", null ],
    [ "PrimvarRefinerReal< float >", "a00817.html", [
      [ "PrimvarRefiner", "a00825.html", null ]
    ] ],
    [ "PtexIndices", "a00829.html", null ],
    [ "Refinement", "a01205.html", null ],
    [ "Refinement::Relations", "a01221.html", null ],
    [ "Scheme< SCHEME_TYPE >", "a01133.html", null ],
    [ "SchemeTypeTraits", "a01141.html", null ],
    [ "SparseSelector", "a01225.html", null ],
    [ "Refinement::SparseTag", "a01213.html", null ],
    [ "StackBuffer< TYPE, SIZE, POD_TYPE >", "a01229.html", null ],
    [ "StencilReal< REAL >", "a00841.html", [
      [ "LimitStencilReal< REAL >", "a00857.html", null ]
    ] ],
    [ "StencilReal< float >", "a00841.html", [
      [ "LimitStencilReal< float >", "a00857.html", [
        [ "LimitStencil", "a00861.html", null ]
      ] ],
      [ "Stencil", "a00845.html", null ]
    ] ],
    [ "StencilTableFactoryReal< REAL >", "a00833.html", null ],
    [ "StencilTableFactoryReal< float >", "a00833.html", [
      [ "StencilTableFactory", "a00885.html", null ]
    ] ],
    [ "StencilTableReal< REAL >", "a00849.html", [
      [ "LimitStencilTableReal< REAL >", "a00865.html", null ]
    ] ],
    [ "StencilTableReal< float >", "a00849.html", [
      [ "LimitStencilTableReal< float >", "a00865.html", [
        [ "LimitStencilTable", "a00869.html", null ]
      ] ],
      [ "StencilTable", "a00853.html", null ]
    ] ],
    [ "TbbEvaluator", "a01109.html", null ],
    [ "TopologyDescriptor", "a00893.html", null ],
    [ "TopologyLevel", "a00901.html", null ],
    [ "TopologyRefiner", "a00909.html", null ],
    [ "TopologyRefinerFactoryBase", "a00921.html", [
      [ "TopologyRefinerFactory< MESH >", "a00905.html", null ]
    ] ],
    [ "TopologyRefiner::UniformOptions", "a00913.html", null ],
    [ "FVarLevel::ValueTag", "a01173.html", null ],
    [ "VertexInterface", "a01161.html", null ],
    [ "Level::VSpan", "a01201.html", null ],
    [ "Level::VTag", "a01189.html", null ]
];
